self.__BUILD_MANIFEST=function(e){return{__rewrites:{afterFiles:[],beforeFiles:[],fallback:[]},"/":[e,"static/chunks/pages/index-924731477de6086e.js"],"/_error":["static/chunks/pages/_error-ee5b5fb91d29d86f.js"],"/experiment/[id]":[e,"static/chunks/pages/experiment/[id]-0c1e6ac6ec0ffa1a.js"],sortedPages:["/","/_app","/_error","/experiment/[id]"]}}("static/chunks/714-6edbaa8bf00e2358.js"),self.__BUILD_MANIFEST_CB&&self.__BUILD_MANIFEST_CB();